@@ -153,21 +153,24 @@ class AutoMLTrainModelOperator(GoogleCloudBaseOperator):
         project_id = self.project_id or hook.project_id
         if project_id:
             TranslationLegacyModelTrainLink.persist(
-                context=context, task_instance=self, project_id=project_id
+                context=context,
+                dataset_id=self.model["dataset_id"],
+                project_id=project_id,
+                location=self.location,
             )
         operation_result = hook.wait_for_operation(timeout=self.timeout, operation=operation)
         result = Model.to_dict(operation_result)
         model_id = hook.extract_object_id(result)
         self.log.info("Model is created, model_id: %s", model_id)
 
-        self.xcom_push(context, key="model_id", value=model_id)
+        context["task_instance"].xcom_push(key="model_id", value=model_id)
         if project_id:
             TranslationLegacyModelLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=self.model["dataset_id"] or "-",
                 model_id=model_id,
                 project_id=project_id,
+                location=self.location,
             )
         return result
 
@@ -259,11 +262,11 @@ class AutoMLPredictOperator(GoogleCloudBaseOperator):
                 gcp_conn_id=self.gcp_conn_id,
                 impersonation_chain=self.impersonation_chain,
             )
-        else:  # endpoint_id defined
-            return PredictionServiceHook(
-                gcp_conn_id=self.gcp_conn_id,
-                impersonation_chain=self.impersonation_chain,
-            )
+        # endpoint_id defined
+        return PredictionServiceHook(
+            gcp_conn_id=self.gcp_conn_id,
+            impersonation_chain=self.impersonation_chain,
+        )
 
     @cached_property
     def model(self) -> Model | None:
@@ -313,10 +316,10 @@ class AutoMLPredictOperator(GoogleCloudBaseOperator):
         if project_id and self.model_id and dataset_id:
             TranslationLegacyModelPredictLink.persist(
                 context=context,
-                task_instance=self,
                 model_id=self.model_id,
                 dataset_id=dataset_id,
                 project_id=project_id,
+                location=self.location,
             )
         return PredictResponse.to_dict(result)
 
@@ -412,14 +415,14 @@ class AutoMLCreateDatasetOperator(GoogleCloudBaseOperator):
         dataset_id = hook.extract_object_id(result)
         self.log.info("Creating completed. Dataset id: %s", dataset_id)
 
-        self.xcom_push(context, key="dataset_id", value=dataset_id)
+        context["task_instance"].xcom_push(key="dataset_id", value=dataset_id)
         project_id = self.project_id or hook.project_id
         if project_id:
             TranslationLegacyDatasetLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=dataset_id,
                 project_id=project_id,
+                location=self.location,
             )
         return result
 
@@ -530,9 +533,9 @@ class AutoMLImportDataOperator(GoogleCloudBaseOperator):
         if project_id:
             TranslationLegacyDatasetLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=self.dataset_id,
                 project_id=project_id,
+                location=self.location,
             )
 
 
@@ -649,9 +652,9 @@ class AutoMLTablesListColumnSpecsOperator(GoogleCloudBaseOperator):
         if project_id:
             TranslationLegacyDatasetLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=self.dataset_id,
                 project_id=project_id,
+                location=self.location,
             )
         return result
 
@@ -749,9 +752,9 @@ class AutoMLTablesUpdateDatasetOperator(GoogleCloudBaseOperator):
         if project_id:
             TranslationLegacyDatasetLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=hook.extract_object_id(self.dataset),
                 project_id=project_id,
+                location=self.location,
             )
         return Dataset.to_dict(result)
 
@@ -845,10 +848,10 @@ class AutoMLGetModelOperator(GoogleCloudBaseOperator):
         if project_id:
             TranslationLegacyModelLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=model["dataset_id"],
                 model_id=self.model_id,
                 project_id=project_id,
+                location=self.location,
             )
         return model
 
@@ -1154,9 +1157,9 @@ class AutoMLTablesListTableSpecsOperator(GoogleCloudBaseOperator):
         if project_id:
             TranslationLegacyDatasetLink.persist(
                 context=context,
-                task_instance=self,
                 dataset_id=self.dataset_id,
                 project_id=project_id,
+                location=self.location,
             )
         return result
 
@@ -1245,14 +1248,13 @@ class AutoMLListDatasetOperator(GoogleCloudBaseOperator):
             result.append(Dataset.to_dict(dataset))
         self.log.info("Datasets obtained.")
 
-        self.xcom_push(
-            context,
+        context["task_instance"].xcom_push(
             key="dataset_id_list",
             value=[hook.extract_object_id(d) for d in result],
         )
         project_id = self.project_id or hook.project_id
         if project_id:
-            TranslationDatasetListLink.persist(context=context, task_instance=self, project_id=project_id)
+            TranslationDatasetListLink.persist(context=context, project_id=project_id)
         return result
 
 
