@@ -33,7 +33,12 @@ from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.cloud_composer import CloudComposerHook
 from airflow.providers.google.cloud.triggers.cloud_composer import CloudComposerDAGRunTrigger
 from airflow.providers.google.common.consts import GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME
-from airflow.sensors.base import BaseSensorOperator
+from airflow.providers.google.version_compat import AIRFLOW_V_3_0_PLUS
+
+if AIRFLOW_V_3_0_PLUS:
+    from airflow.sdk import BaseSensorOperator
+else:
+    from airflow.sensors.base import BaseSensorOperator  # type: ignore[no-redef]
 from airflow.utils.state import TaskInstanceState
 
 if TYPE_CHECKING:
@@ -108,14 +113,12 @@ class CloudComposerDAGRunSensor(BaseSensorOperator):
         if isinstance(self.execution_range, timedelta):
             if self.execution_range < timedelta(0):
                 return context["logical_date"], context["logical_date"] - self.execution_range
-            else:
-                return context["logical_date"] - self.execution_range, context["logical_date"]
-        elif isinstance(self.execution_range, list) and len(self.execution_range) > 0:
+            return context["logical_date"] - self.execution_range, context["logical_date"]
+        if isinstance(self.execution_range, list) and len(self.execution_range) > 0:
             return self.execution_range[0], self.execution_range[1] if len(
                 self.execution_range
             ) > 1 else context["logical_date"]
-        else:
-            return context["logical_date"] - timedelta(1), context["logical_date"]
+        return context["logical_date"] - timedelta(1), context["logical_date"]
 
     def poke(self, context: Context) -> bool:
         start_date, end_date = self._get_logical_dates(context)
