@@ -19,9 +19,9 @@
 
 from __future__ import annotations
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from functools import cached_property
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException
@@ -37,7 +37,7 @@ from airflow.providers.google.cloud.triggers.dataflow import (
     DataflowJobStatusTrigger,
 )
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
-from airflow.sensors.base import BaseSensorOperator
+from airflow.providers.google.version_compat import BaseSensorOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -117,7 +117,7 @@ class DataflowJobStatusSensor(BaseSensorOperator):
 
         if job_status in self.expected_statuses:
             return True
-        elif job_status in DataflowJobStatus.TERMINAL_STATES:
+        if job_status in DataflowJobStatus.TERMINAL_STATES:
             message = f"Job with id '{self.job_id}' is already in terminal state: {job_status}"
             raise AirflowException(message)
 
