@@ -21,6 +21,7 @@ Example Airflow DAG that performs query in a Cloud SQL instance.
 
 from __future__ import annotations
 
+import json
 import logging
 import os
 from collections import namedtuple
@@ -32,9 +33,7 @@ from typing import Any
 
 from googleapiclient import discovery
 
-from airflow import settings
 from airflow.decorators import task, task_group
-from airflow.models.connection import Connection
 from airflow.models.dag import DAG
 from airflow.providers.google.cloud.operators.cloud_sql import (
     CloudSQLCreateInstanceDatabaseOperator,
@@ -42,11 +41,11 @@ from airflow.providers.google.cloud.operators.cloud_sql import (
     CloudSQLDeleteInstanceOperator,
     CloudSQLExecuteQueryOperator,
 )
-from airflow.settings import Session
 from airflow.utils.trigger_rule import TriggerRule
 
 from system.google import DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
 from system.openlineage.operator import OpenLineageTestOperator
+from tests_common.test_utils.api_client_helpers import create_airflow_connection, delete_airflow_connection
 
 ENV_ID = os.environ.get("SYSTEM_TESTS_ENV_ID", "default")
 PROJECT_ID = os.environ.get("SYSTEM_TESTS_GCP_PROJECT") or DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
@@ -108,17 +107,16 @@ def ip_configuration() -> dict[str, Any]:
             "enablePrivatePathForGoogleCloudServices": True,
             "privateNetwork": f"projects/{PROJECT_ID}/global/networks/default",
         }
-    else:
-        # Use connection to Cloud SQL instance via Public IP from anywhere (mask 0.0.0.0/0).
-        # Consider specifying your network mask
-        # for allowing requests only from the trusted sources, not from anywhere.
-        return {
-            "ipv4Enabled": True,
-            "requireSsl": False,
-            "authorizedNetworks": [
-                {"value": "0.0.0.0/0"},
-            ],
-        }
+    # Use connection to Cloud SQL instance via Public IP from anywhere (mask 0.0.0.0/0).
+    # Consider specifying your network mask
+    # for allowing requests only from the trusted sources, not from anywhere.
+    return {
+        "ipv4Enabled": True,
+        "requireSsl": False,
+        "authorizedNetworks": [
+            {"value": "0.0.0.0/0"},
+        ],
+    }
 
 
 def cloud_sql_instance_create_body(database_provider: dict[str, Any]) -> dict[str, Any]:
@@ -455,20 +453,16 @@ with DAG(
             port: str,
             kwargs: dict[str, Any],
         ) -> str | None:
-            session = settings.Session()
-            log.info("Removing connection %s if it exists", connection_id)
-            query = session.query(Connection).filter(Connection.conn_id == connection_id)
-            query.delete()
-
             connection: dict[str, Any] = deepcopy(kwargs)
             connection["extra"]["instance"] = instance
             connection["host"] = ip_address
             connection["extra"]["database_type"] = db_type
             connection["port"] = port
-            _conn = Connection(conn_id=connection_id, **connection)
-            session.add(_conn)
-            session.commit()
-            log.info("Connection created: '%s'", connection_id)
+            connection["extra"] = json.dumps(connection["extra"])
+            create_airflow_connection(
+                connection_id=connection_id,
+                connection_conf=connection,
+            )
             return connection_id
 
         @task_group(group_id=f"create_connections_{database_type}")
@@ -514,11 +508,7 @@ with DAG(
 
         @task()
         def delete_connection(connection_id: str) -> None:
-            session = Session()
-            log.info("Removing connection %s", connection_id)
-            query = session.query(Connection).filter(Connection.conn_id == connection_id)
-            query.delete()
-            session.commit()
+            delete_airflow_connection(connection_id=connection_id)
 
         delete_connections_task = delete_connection.expand(
             connection_id=[f"{conn.id}_{database_type}" for conn in CONNECTIONS]
