@@ -483,9 +483,7 @@ class TestGKECreateClusterOperator:
 
         result = self.operator.execute(context=mock_context)
 
-        mock_link.persist.assert_called_once_with(
-            context=mock_context, task_instance=self.operator, cluster=GKE_CLUSTER_CREATE_BODY_DICT
-        )
+        mock_link.persist.assert_called_once_with(context=mock_context, cluster=GKE_CLUSTER_CREATE_BODY_DICT)
         mock_create_cluster.assert_called_once_with(
             cluster=GKE_CLUSTER_CREATE_BODY_DICT,
             project_id=TEST_PROJECT_ID,
@@ -506,9 +504,7 @@ class TestGKECreateClusterOperator:
 
         result = self.operator.execute(context=mock_context)
 
-        mock_link.persist.assert_called_once_with(
-            context=mock_context, task_instance=self.operator, cluster=GKE_CLUSTER_CREATE_BODY_DICT
-        )
+        mock_link.persist.assert_called_once_with(context=mock_context, cluster=GKE_CLUSTER_CREATE_BODY_DICT)
         mock_create_cluster.assert_called_once_with(
             cluster=GKE_CLUSTER_CREATE_BODY_DICT,
             project_id=TEST_PROJECT_ID,
@@ -535,9 +531,7 @@ class TestGKECreateClusterOperator:
 
         self.operator.execute(context=mock_context)
 
-        mock_link.persist.assert_called_once_with(
-            context=mock_context, task_instance=self.operator, cluster=GKE_CLUSTER_CREATE_BODY_DICT
-        )
+        mock_link.persist.assert_called_once_with(context=mock_context, cluster=GKE_CLUSTER_CREATE_BODY_DICT)
         mock_create_cluster.assert_called_once_with(
             cluster=GKE_CLUSTER_CREATE_BODY_DICT,
             project_id=TEST_PROJECT_ID,
@@ -621,7 +615,6 @@ class TestGKEStartKueueInsideClusterOperator:
         )
         mock_link.persist.assert_called_once_with(
             context=mock_context,
-            task_instance=self.operator,
             cluster=mock_cluster,
         )
         mock_check_cluster_autoscaling_ability.assert_called_once_with(cluster=mock_cluster)
@@ -647,7 +640,6 @@ class TestGKEStartKueueInsideClusterOperator:
         )
         mock_link.persist.assert_called_once_with(
             context=mock_context,
-            task_instance=self.operator,
             cluster=mock_cluster,
         )
         mock_check_cluster_autoscaling_ability.assert_called_once_with(cluster=mock_cluster)
@@ -933,7 +925,14 @@ class TestGKEDescribeJobOperator:
             GKE_CLUSTER_NAME,
             mock_job,
         )
-        mock_link.persist.assert_called_once_with(context=mock_context, task_instance=self.operator)
+        mock_link.persist.assert_called_once_with(
+            context=mock_context,
+            project_id=TEST_PROJECT_ID,
+            location=TEST_LOCATION,
+            cluster_name=GKE_CLUSTER_NAME,
+            namespace=mock_job.metadata.namespace,
+            job_name=mock_job.metadata.name,
+        )
 
 
 class TestGKEListJobsOperator:
@@ -949,12 +948,11 @@ class TestGKEListJobsOperator:
         expected_template_fields = {"namespace"} | set(GKEOperatorMixin.template_fields)
         assert set(GKEListJobsOperator.template_fields) == expected_template_fields
 
-    @mock.patch(GKE_OPERATORS_PATH.format("KubernetesEngineWorkloadsLink"))
     @mock.patch(GKE_OPERATORS_PATH.format("V1JobList.to_dict"))
     @mock.patch(GKE_OPERATORS_PATH.format("GKEListJobsOperator.log"))
     @mock.patch(GKE_OPERATORS_PATH.format("GKEHook"))
     @mock.patch(GKE_OPERATORS_PATH.format("GKEKubernetesHook"))
-    def test_execute(self, mock_hook, cluster_hook, mock_log, mock_to_dict, mock_link):
+    def test_execute(self, mock_hook, cluster_hook, mock_log, mock_to_dict):
         mock_list_jobs_from_namespace = mock_hook.return_value.list_jobs_from_namespace
         mock_list_jobs_all_namespaces = mock_hook.return_value.list_jobs_all_namespaces
         mock_job_1, mock_job_2 = mock.MagicMock(), mock.MagicMock()
@@ -963,7 +961,7 @@ class TestGKEListJobsOperator:
         mock_to_dict_value = mock_to_dict.return_value
 
         mock_ti = mock.MagicMock()
-        context = {"ti": mock_ti}
+        context = {"ti": mock_ti, "task": mock.MagicMock()}
 
         result = self.operator.execute(context=context)
 
@@ -976,8 +974,9 @@ class TestGKEListJobsOperator:
             ]
         )
         mock_to_dict.assert_has_calls([call(mock_jobs), call(mock_jobs)])
-        mock_ti.xcom_push.assert_called_once_with(key="jobs_list", value=mock_to_dict_value)
-        mock_link.persist.assert_called_once_with(context=context, task_instance=self.operator)
+        mock_ti.xcom_push.assert_has_calls(
+            [call(key="jobs_list", value=mock_to_dict_value), call(key="kubernetes_workloads_conf", value={})]
+        )
         assert result == mock_to_dict_value
 
     @mock.patch(GKE_OPERATORS_PATH.format("KubernetesEngineWorkloadsLink"))
@@ -994,7 +993,7 @@ class TestGKEListJobsOperator:
         mock_to_dict_value = mock_to_dict.return_value
 
         mock_ti = mock.MagicMock()
-        context = {"ti": mock_ti}
+        context = {"ti": mock_ti, "task": mock.MagicMock()}
 
         self.operator.namespace = K8S_NAMESPACE
         result = self.operator.execute(context=context)
@@ -1009,7 +1008,7 @@ class TestGKEListJobsOperator:
         )
         mock_to_dict.assert_has_calls([call(mock_jobs), call(mock_jobs)])
         mock_ti.xcom_push.assert_called_once_with(key="jobs_list", value=mock_to_dict_value)
-        mock_link.persist.assert_called_once_with(context=context, task_instance=self.operator)
+        mock_link.persist.assert_called_once_with(context=context)
         assert result == mock_to_dict_value
 
     @mock.patch(GKE_OPERATORS_PATH.format("KubernetesEngineWorkloadsLink"))
@@ -1026,7 +1025,7 @@ class TestGKEListJobsOperator:
         mock_to_dict_value = mock_to_dict.return_value
 
         mock_ti = mock.MagicMock()
-        context = {"ti": mock_ti}
+        context = {"ti": mock_ti, "task": mock.MagicMock()}
 
         self.operator.do_xcom_push = False
         result = self.operator.execute(context=context)
@@ -1040,8 +1039,7 @@ class TestGKEListJobsOperator:
             ]
         )
         mock_to_dict.assert_called_once_with(mock_jobs)
-        mock_ti.xcom_push.assert_not_called()
-        mock_link.persist.assert_called_once_with(context=context, task_instance=self.operator)
+        mock_link.persist.assert_called_once_with(context=context)
         assert result == mock_to_dict_value
 
 
@@ -1188,7 +1186,14 @@ class TestGKESuspendJobOperator:
             K8S_JOB_NAME,
             GKE_CLUSTER_NAME,
         )
-        mock_link.persist.assert_called_once_with(context=mock_context, task_instance=self.operator)
+        mock_link.persist.assert_called_once_with(
+            context=mock_context,
+            project_id=TEST_PROJECT_ID,
+            location=TEST_LOCATION,
+            cluster_name=GKE_CLUSTER_NAME,
+            namespace=mock_job.metadata.namespace,
+            job_name=mock_job.metadata.name,
+        )
         mock_to_dict.assert_called_once_with(mock_job)
         assert result == expected_result
 
@@ -1231,6 +1236,13 @@ class TestGKEResumeJobOperator:
             K8S_JOB_NAME,
             GKE_CLUSTER_NAME,
         )
-        mock_link.persist.assert_called_once_with(context=mock_context, task_instance=self.operator)
+        mock_link.persist.assert_called_once_with(
+            context=mock_context,
+            project_id=TEST_PROJECT_ID,
+            location=TEST_LOCATION,
+            cluster_name=GKE_CLUSTER_NAME,
+            namespace=mock_job.metadata.namespace,
+            job_name=mock_job.metadata.name,
+        )
         mock_to_dict.assert_called_once_with(mock_job)
         assert result == expected_result
